<template>
  <v-app light :class="$route.name">
      <!-- <v-navigation-drawer
        fixed
        class="left_sidebar"
        width="320"
        floating
        left
        permanent
        app
        clipped
      >
        <MainSidebar></MainSidebar>
      </v-navigation-drawer> -->

      <v-dialog
        temporary
        v-model="cart_drawer"
        fullscreen
        hide-overlay
        transition="dialog-bottom-transition"
      >
        <v-card>
            <v-toolbar dark color="secondary">
                <v-btn icon dark @click="cart_drawer = false">
                  <v-icon light>close</v-icon>
                </v-btn>
                <v-toolbar-title>Cart</v-toolbar-title>
                <v-spacer></v-spacer>
                <v-toolbar-items>
                  <v-btn 
                    dark 
                    flat
                    to="/order"
                  >Checkout</v-btn>
                </v-toolbar-items>
            </v-toolbar>
            <cart :cart_drawer="cart_drawer" :config="cart"></cart>
        </v-card>
      </v-dialog>

      <v-navigation-drawer
        temporary
        v-model="sidebar"
        width="300"
        fixed>
        <sidebar></sidebar>
      </v-navigation-drawer>

        <mobile-check
            v-if="$store.state.customer && $store.state.customer.id && !$store.state.customer.mobile"
            :layout="this"
            :info="info"
            :customer="$store.state.customer"
        ></mobile-check>

        <v-content v-if="$route.name != 'index'">
          <main-header @drawer="openDrawer" :layout="this"></main-header>
          <v-container class="pa-0">
            <nuxt />
          </v-container>
          <foo :customer="$store.state.customer"></foo>
        </v-content>

        <v-content v-else>
          <main-header 
            @drawer="openDrawer"
          >
          </main-header>
          <nuxt />
          <foo :customer="$store.state.customer"></foo>
        </v-content>
    
      <v-snackbar
        :timeout="getNumber(0)"
        bottom 
        dark
        left
        color="secondary"
        v-model="$store.state.snackbar">
        {{ $store.state.snackbar_text }}
        <v-btn
          color="primary"
          flat
          @click="$store.commit('hideSnackBar')">
          Close
        </v-btn>
      </v-snackbar>
  </v-app>
</template>

<script>
import axios from 'axios';
import Vue from 'vue';
import Cart from '~/components/cart.vue';
import Sidebar from '~/components/sidebarMenu.vue';
import Footer from '~/components/footer.vue';
import Header from '~/components/Header.vue';
import mobileCheck from '~/components/MobileCheck.vue';
import Lazy from '~/components/Lazy'
import MainSidebar from '~/components/MainSidebar'
import HomeTopBlock from '~/components/HomeTopBlock'

Vue.component('cart', Cart);
Vue.component('sidebar', Sidebar);
Vue.component('foo', Footer);
Vue.component('main-header', Header);
Vue.component('mobile-check', mobileCheck);
Vue.component('Lazy', Lazy)
Vue.component('MainSidebar', MainSidebar)
Vue.component('HomeTopBlock', HomeTopBlock)

export default {
    data () {
      return {
        sidebar: null,
        cart: {
          temporary: true,
          permanent: false,
          fixed: true,
        },
        clipped: true,
        fixed: false,
        miniVariant: false,
        right: true,
        rightDrawer: false,
        noMobile: false,
        info: false,
      }
    },
    methods: {
      openDrawer () {
        this.sidebar = true;
      },
      getNumber: function (val) {
        return +val;
      },
      checkCart: function () {
        var form_data = new FormData;
        form_data.append('test', 'test');
        axios.post(this.$store.state.api_domain + '?comp=process&action=checkCart', form_data, {
          withCredentials: true
        }).then((res) => {
          if (res.data.status == 'success') {
            this.$store.commit('setCart', res.data.message);
          }
        });
      },
      qtyChange: function (data) {
        this.$store.commit('setCartError', false);
        var product = data.product;
        var qty = +data.qty;
        var minimal = +data.product.minimal_quantity;

        if (qty < minimal) {
          this.$store.commit('setCartError', 'Quantity cannot go below minimal ' + minimal);
          this.checkCart();
          var store = this.$store;
          setTimeout(function () {
            store.commit('setCartError', false);
          }, 7000);
          return false;
        }

        var form_data = new FormData();
        form_data.append('id_product', product.id_product);
        form_data.append('id_product_attribute', product.id_product_attribute);
        form_data.append('qty', qty);

        axios.post(this.$store.state.api_domain + '?comp=process&action=qtyChange', form_data, {
          withCredentials: true
        }).then((res) => {
          this.$store.commit('setCart', res.data.message);
        });
      }
    },
    computed: {
        cart_drawer: {
          get() {
            return this.$store.state.cart_drawer
          },
          set(val) {
            this.$store.commit('cartDrawer', val);
          }
        }
    },
    created () {
        axios.get(this.$store.state.api_domain + '?comp=core', {
          withCredentials: true
        }).then((res) => {
          if (res.data.core.cart) {
            this.$store.commit('setCart', res.data.core.cart);
          }
          if (res.data.core.customer) {
            this.$store.commit('setCustomer', res.data.core.customer);
          }
        });
    }
  }
</script>
